Court of Appeals Webcast Archive - 2014 Term

- 361 Rowe Boulevard
- Annapolis, MD 21401
- 410-260-1500 • 800-926-2583 • TTY 410-260-1554
- Hours of Operation: 8:00 a.m. - 4:30 p.m.

## Court of Appeals

### Robert C. Murphy Courts of Appeal Building

# Court of Appeals Webcast Archive

SEPTEMBER TERM 2014 Webcasts
October 2014 Oral Arguments
September 2014 Oral Arguments

Oral Arguments Archives
September Term 2013 Webcasts
September Term 2012 Webcasts
September Term 2011 Webcasts
September Term 2010 Webcasts
September Term 2009 Webcasts
September Term 2008 Webcasts
September Term 2007 Webcasts
September Term 2006 Webcasts

To view the Webcast, you must have Windows Media version 9 or higher. This FREE software can be downloaded to your computer.
Download the FREE Media Player

October 2014 Schedule
Date | Docket # | Title
10-07-2014 | AG No. 61 (2013 T.) | Attorney Grievance Commission of Maryland v. Michael C. Hodes
10-07-2014 | AG No. 63 (2013 T.) | Attorney Grievance Commission of Maryland v. Gayton J. Thomas, Jr.
10-07-2014 | No. 15 | State of Maryland v. Kenneth Martin Stachowski, Jr. Issues – Criminal Law – 1) Did CSA err in holding that a court may not order restitution as part of a plea agreement on a charge as a condition of a probation in another matter before the court, creating uncertainty in conflict with this Court’s holdings in Walczak and Lee? 2) Did CSA err in vacating only the negotiated and accepted restitution condition required of Petitioner, which was part of the plea agreement, rather than rescinding the entire plea agreement, thus allowing Petitioner the full benefit of his bargain with the State without assuming any of his negotiated burden?
10-07-2014 | No. 102 (2013 T.) | Steven M. Johnson v. State of Maryland DNA Appeal
10-06-2014 | AG No. 17 (2013 T.) | Attorney Grievance Commission of Maryland v. Patrick Guy Samuel Marie Merkle
10-06-2014 | No. 13 | Jerrod M. Peterson v. State of Maryland Issues – Criminal Law – 1) Did the trial court err in ruling that the attorney-client privilege prevented the co-conspirator’s attorney from testifying about the co-conspirator’s proffer session with a prosecutor and a county homicide detective? 2) Was Petitioner’s Sixth Amendment Right of Confrontation violated when the trial court limited his cross-examination of multiple State witnesses? 3) Did the trial court commit reversible error by limiting Petitioner’s cross-examination of multiple State witnesses? 4) Are Petitioner’s claims regarding cross-examination of witnesses properly before this Court for review?
10-06-2014 | No. 14 | Kevin E. Jones v. State of Maryland Issue – Criminal Law – Was the evidence sufficient to convict Petitioner of second degree assault of the intent to frighten modality where the State failed to prove that Petitioner was aware of the existence of the victim?
10-03-2014 | AG No. 99 (2013 T.) | Attorney Grievance Commission of Maryland v. Talieb Nilaja Wills
10-03-2014 | AG No. 28 (2013 T.) | Attorney Grievance Commission of Maryland v. Michael Francis Barnett
10-03-2014 | No. 18 | Gineene Williams, etc., et al. v. Peninsula Regional Medical Center, et al. Issue – Torts – Does MD’s involuntary admission immunity statute, Health General § 10-618, apply to health care providers who evaluate an individual and decide to discharge the patient from psychiatric care?
10-02-2014 | Bar Admissions |
10-02-2014 | AG No. 2 | Attorney Grievance Commission of Maryland v. Christopher W. Poverman
10-02-2014 | AG No. 14 (2013 T.) | Attorney Grievance Commission of Maryland v. Michael Craig Worsham
10-02-2014 | No. 16 | Traimne Martinez Allen v. State of Maryland Did the lower court err in reading MD Code, Public Safety Art., § 2-510, so broadly as to conclude that crime scene DNA of other suspects – one of whom had a conviction for a crime very similar to the events for which Petitioner stood trial – was not admissible at trial, and was Petitioner denied his constitutional right to present a defense?
10-02-2014 | No. 17 | Howard Bay Diggs v. State of Maryland Issues – Criminal Law – 1) Does MD Code, Public Safety Art., §2-510, which provides that “a DNA database match may be used to establish probable cause to charge and arrest an individual” but “the database match would be inadmissible at a trial of that individual…,” prohibit the introduction at trial by a criminal defendant of evidence of DNA matches to alternative suspects; and if so, does §2-510 deny a criminal defendant his/her constitutional right to present a defense? 2) Did the trial court err in excluding evidence offered by Petitioner of DNA database matches to other suspects on evidence collected at the crime scene?
September 2014 Schedule
Date | Docket # | Title
09-10-2014 | AG No. 33 (2013 T.) | Attorney Grievance Commission of Maryland v. Thomas Wesley Felder, II
09-10-2014 | AG No. 5 (2013 T.) | Attorney Grievance Commission of Maryland v. Sandra Lynn Reno
09-10-2014 | No. 85 (2013 T.) | State of Maryland v. Joseph William Payne & Jason Bond Issues – Criminal Law – 1) May a trial court allow a lay witness, without qualification as an expert, to testify about objectively verifiable facts regarding cell phone towers that do not involve the witness forming any opinion or drawing any inference or conclusion? 2) Did CSA err in ruling that wiretap statements made by Respondent Bond but not Respondent Payne were nevertheless admissible against Payne as statements by a party-opponent?
09-10-2014 | No. 4 | Deborah Hiob, et al. v. Progressive American Insurance Company, et al. Issues – Civil Procedure – 1) Did CSA err in holding that a partial voluntary dismissal can constitute an appropriate “separate document” for the purpose of Maryland Rule 2-601 even though that document is not signed by the clerk or the court? 2) Whether judgment was entered on the date the clerk entered the court’s order entering judgment and whether the notice of appeal filed prior to that docket entry is a premature appeal saved by the provisions of Rule 8-602(d)?
09-09-2014 | AG No. 73 (2012 T.) | Attorney Grievance Commission of Maryland v. Joseph Mua Kum
09-09-2014 | AG No. 72 (2012 T.) | Attorney Grievance Commission of Maryland v. Scott Gregory Adams
09-09-2014 | No. 2 | John S. Burson, et al. v. Jeffrey G. Capps Issues – Financial Institutions – 1) Whether a Truth-in-Lending Act (“TILA”) Notice of Rescission can be effective to cancel a loan transaction that has not yet taken place, and remain effective despite the issuing party’s subsequent acceptance of the benefits of the transaction? 2) Whether a TILA action filed in December 2009 on the basis of a Notice of Rescission issued in April 2007 was untimely as beyond the one-year statute of limitation in 15 U.S.C. § 1640(e)? 3) Whether rescission is an available remedy when the trial court has no jurisdiction over either the original lender or its assignee because all claims against both have been dismissed, with no appeal taken from that dismissal?
09-04-2014 | AG No. 10 (2013 T.) | Attorney Grievance Commission of Maryland v. Daun Robert Weiers
09-04-2014 | AG No. 36 (2013 T.) | Attorney Grievance Commission of Maryland v. Jason Robin Gelb
09-04-2014 | AG No. 16 (2013 T.) | Attorney Grievance Commission of Maryland v. Ronald Claude Brigerman, Jr.
09-04-2014 | No. 99 (2013 T.) | Luther Gales, III v. Sunoco, Inc. and American Zurich Insurance Issue – Workers’ Compensation – Are Appellants in a de novo workers’ compensation appeal required to admit into evidence the award from which the appeal was taken as an element of their burden of proof?
09-03-2014 | Bar Admissions |
09-03-2014 | AG No. 81 (2013 T.) | Attorney Grievance Commission of Maryland v. Donald Saunders Litman
09-03-2014 | AG No. 25 (2013 T.) | Attorney Grievance Commission of Maryland v. Christine Boco Gage-Cohen
09-03-2014 | AG No. 49 (2013 T.) | Attorney Grievance Commission of Maryland v. Floyd Reynard Blair
09-03-2014 | No. 3 | State of Maryland v. Jonathan Johnson Issue – Criminal Law – Is a “suggestion” by the defendant that the victim’s mental health records may contain information that is either exculpatory or relating to the victim’s “propensity for veracity,” not sufficient, under Goldsmith v. State, 337 Md. 112 (1995), to “call for an in camera review” of those records?
09-03-2014 | No. 97 (2013 T.) | Gregory Howard v. State of Maryland Issues – Criminal Law – 1) Did the trial court err in refusing Petitioner’s request for a postponement without sending the matter to the administrative judge or its designee? 2) Did the trial court fail to make the necessary inquiry regarding Petitioner’s request for counsel before denying the request for a postponement? 3) Did the trial court err in finding that Petitioner’s waiver of counsel resulted in a concomitant waiver of the right to discovery? 4) Was Petitioner deprived of his constitutional right to a speedy trial?